# About this Notebooks directory

This repository is used to store notebooks that are
used to generate our documentation website tutorials.
(Some notebooks will not render on GitHub, but they can still be openned in Colab.)

`TODO: document build process. link to notebooks in repo, notebooks on website, and notebooks on colab.
